#
# spec file for package transmission
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           transmission
Version:        2.84
Release:        8.3
Summary:        Lightweight, yet powerful BitTorrent client
License:        (GPL-2.0 or GPL-3.0) and MIT
Group:          Productivity/Networking/Other
Url:            http://www.transmissionbt.com/
Source0:        http://download.m0k.org/transmission/files/%{name}-%{version}.tar.xz
Source1:        transmission-qt.desktop
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
%if 0%{?WITH_APPINDICATOR}
BuildRequires:  libappindicator-devel >= 0.4.90
%endif
Source2:        transmission-daemon-systemd
Source3:        README.openSUSE
BuildRequires:  libcurl-devel
BuildRequires:  libevent-devel >= 2.0.0
BuildRequires:  libminiupnpc-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  openssl-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4.0
BuildRequires:  pkgconfig(libsystemd-daemon)
Requires:       %{name}-common = %{version}
Provides:       %{name}-ui = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
Transmission is a fast, easy, and free multi-platform BitTorrent client
with a focus on being lightweight yet feature-filled. Its simple,
intuitive interface is designed to integrate tightly with whatever
computing environment you choose to use. Transmission strikes a balance
between providing useful functionality without feature bloat.
Furthermore, it is free for anyone to use or modify.

%package gtk
Summary:        Lightweight, yet powerful BitTorrent client
Group:          Productivity/Networking/Other
Requires:       %{name}-common = %{version}
# For canberra-gtk-play binary
Requires:       canberra-gtk-play
Recommends:     %{name}-gtk-lang
Provides:       %{name}-ui = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description gtk
Transmission is a fast, easy, and free multi-platform BitTorrent client
with a focus on being lightweight yet feature-filled. Its simple,
intuitive interface is designed to integrate tightly with whatever
computing environment you choose to use. Transmission strikes a balance
between providing useful functionality without feature bloat.
Furthermore, it is free for anyone to use or modify.

This package contains a graphical user interface to transmission.

%package qt
Summary:        Lightweight, yet powerful BitTorrent client
Group:          Productivity/Networking/Other
Requires:       %{name}-common = %{version}
Recommends:     %{name}-qt-lang
Provides:       %{name}-ui = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description qt
Transmission is a fast, easy, and free multi-platform BitTorrent client
with a focus on being lightweight yet feature-filled. Its simple,
intuitive interface is designed to integrate tightly with whatever
computing environment you choose to use. Transmission strikes a balance
between providing useful functionality without feature bloat.
Furthermore, it is free for anyone to use or modify.

This package contains a graphical user interface to transmission.

%package common
Summary:        Lightweight, yet powerful BitTorrent client - Common Data
Group:          Productivity/Networking/Other
Requires:       %{name}-ui = %{version}
BuildArch:      noarch

%description common
Transmission is a fast, easy, and free multi-platform BitTorrent client
with a focus on being lightweight yet feature-filled. Its simple,
intuitive interface is designed to integrate tightly with whatever
computing environment you choose to use. Transmission strikes a balance
between providing useful functionality without feature bloat.
Furthermore, it is free for anyone to use or modify.

%package daemon
Summary:        Lightweight, yet powerful BitTorrent client - daemon
Group:          Productivity/Networking/Other
%{?systemd_requires}

%description daemon
Transmission is a fast, easy, and free multi-platform BitTorrent client
with a focus on being lightweight yet feature-filled. Its simple,
intuitive interface is designed to integrate tightly with whatever
computing environment you choose to use. Transmission strikes a balance
between providing useful functionality without feature bloat.
Furthermore, it is free for anyone to use or modify.

%lang_package -n %{name}-gtk
%lang_package -n %{name}-qt
%prep
%setup -q
cp %{S:3} .

%build
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%configure \
        --disable-static \
%if 0%{?WITH_APPINDICATOR}
        --enable-libappindicator \
%endif
	--with-gtk
make %{?_smp_mflags}
# the qt ui requires an extrawurst for now
cd qt
qmake-qt5 QMAKE_CXXFLAGS="%{optflags} -fPIC" qtr.pro
make %{?_smp_mflags}
lrelease-qt5 translations/*.ts

%install
%make_install
# install qt ui
cd qt
make install INSTALL_ROOT=%{buildroot}%{_prefix}
install -d %{buildroot}%{_datadir}/qt5/translations/
install -m0644 translations/*.qm %{buildroot}%{_datadir}/qt5/translations/
install -D -m 0644 %{S:2} %{buildroot}%{_unitdir}/transmission-daemon.service
install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rctransmission-daemon
mkdir -p %{buildroot}%{_localstatedir}/lib/transmission
cd ..
# create targets for transmission below /etc/alternatives/
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/transmission %{buildroot}/%{_bindir}/transmission
ln -s -f %{_sysconfdir}/alternatives/transmission.1.gz %{buildroot}/%{_mandir}/man1/transmission.1.gz
%find_lang transmission-gtk %{?no_lang_C}
%find_lang transmission transmission-qt.lang --with-qt --without-mo %{?no_lang_C}
%suse_update_desktop_file transmission-gtk
%suse_update_desktop_file -i transmission-qt
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%pre daemon
getent group transmission >/dev/null || groupadd -r transmission
getent passwd transmission >/dev/null || \
    useradd -r -g transmission -d /var/lib/transmission -s /sbin/nologin \
    -c "Transmission BT daemon user" transmission
%service_add_pre transmission-daemon.service

%post daemon
%service_add_post transmission-daemon.service

%preun daemon
%service_del_preun transmission-daemon.service

%postun daemon
%service_del_postun transmission-daemon.service

%post
update-alternatives --install %{_bindir}/transmission           transmission      %{_bindir}/transmission-cli 5         \
                    --slave   %{_mandir}/man1/transmission.1.gz transmission.1.gz %{_mandir}/man1/transmission-cli.1.gz

%post gtk
update-alternatives --install %{_bindir}/transmission           transmission      %{_bindir}/transmission-gtk 15        \
                    --slave   %{_mandir}/man1/transmission.1.gz transmission.1.gz %{_mandir}/man1/transmission-gtk.1.gz
%desktop_database_post

%post qt
update-alternatives --install %{_bindir}/transmission           transmission      %{_bindir}/transmission-qt 10         \
                    --slave   %{_mandir}/man1/transmission.1.gz transmission.1.gz %{_mandir}/man1/transmission-qt.1.gz
%desktop_database_post

%post common
%icon_theme_cache_post

%postun
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/transmission-cli ]; then
  update-alternatives --remove transmission %{_bindir}/transmission-cli
fi

%postun gtk
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/transmission-gtk ]; then
  update-alternatives --remove transmission %{_bindir}/transmission-gtk
fi
%desktop_database_postun

%postun qt
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/transmission-qt ]; then
  update-alternatives --remove transmission %{_bindir}/transmission-qt
fi
%desktop_database_postun

%postun common
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS NEWS README COPYING README.openSUSE
%{_bindir}/transmission-cli
%{_bindir}/transmission-create
%{_bindir}/transmission-edit
%{_bindir}/transmission-remote
%{_bindir}/transmission-show
%doc %{_mandir}/man1/transmission-cli.1*
%doc %{_mandir}/man1/transmission-create.1*
%doc %{_mandir}/man1/transmission-edit.1*
%doc %{_mandir}/man1/transmission-remote.1*
%doc %{_mandir}/man1/transmission-show.1*
# Update-Alternative managed
%{_bindir}/transmission
%{_mandir}/man1/transmission.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/transmission
%ghost %{_sysconfdir}/alternatives/transmission.1.gz

%files daemon
%defattr(-,root,root)
%doc AUTHORS NEWS README COPYING README.openSUSE
%dir %{_localstatedir}/lib/transmission
%doc %{_mandir}/man1/transmission-daemon.1*
%{_bindir}/transmission-daemon
%{_sbindir}/rctransmission-daemon
%{_unitdir}/transmission-daemon.service
%attr(-,transmission,transmission)%{_localstatedir}/lib/transmission/

%files -n %{name}-gtk-lang -f transmission-gtk.lang
%defattr(-,root,root)

%files gtk
%defattr(-,root,root)
%doc AUTHORS NEWS README COPYING README.openSUSE
%{_bindir}/transmission-gtk
%{_datadir}/applications/transmission-gtk.desktop
%doc %{_mandir}/man1/transmission-gtk.1*
# Update-Alternative managed
%{_bindir}/transmission
%{_mandir}/man1/transmission.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/transmission
%ghost %{_sysconfdir}/alternatives/transmission.1.gz

%files -n %{name}-qt-lang -f transmission-qt.lang
%defattr(-,root,root)
%dir %{_datadir}/qt5
%dir %{_datadir}/qt5/translations

%files qt
%defattr(-,root,root)
%doc AUTHORS NEWS README COPYING README.openSUSE
%{_bindir}/transmission-qt
%{_datadir}/applications/transmission-qt.desktop
%doc %{_mandir}/man1/transmission-qt.1*
# Update-Alternative managed
%{_bindir}/transmission
%{_mandir}/man1/transmission.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/transmission
%ghost %{_sysconfdir}/alternatives/transmission.1.gz

%files common
%defattr(-,root,root)
%{_datadir}/transmission/
%{_datadir}/icons/*/*/apps/transmission.*
%{_datadir}/pixmaps/transmission.png

%changelog
* Mon Jul 21 2014 dimstar@opensuse.org
- Add rctransmission-daemon symlink for convenience.
- Fix usage of update-alternatives.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 2.84 (bnc#887079, CVE-2014-4909):
  + All Platforms: Fix peer communication vulnerability.
- Changes from version 2.83:
  + All Platforms:
  - Licensing change: the GNU GPLv2 code can now be used under
    GNU GPL v2 or v3.
  - Fix network hanging issues that could occur when both UTP and
    DHT were enabled.
  - Fix 2.82 file descriptor leak when importing a blocklist.
  - Disallow torrents that contain "/../" in the path.
  - Fix 2.82 bug that didn't retain peers between sessions.
  - Fix potential dangling memory error in UDP tracker DNS
    lookups.
  - Remember a torrent's "queued" state between Transmission
    sessions.
  - Updated third party libraries: DHT updated to v0.22;
    miniupnpc updated to v1.9.
  - Autoconf script fixes: better detection of ccache, minupnpc.
  - Fix the X-Transmission-Session-Id header to be valid with the
    SPDY protocol.
  - Fix thread safety bugs in the tr_list datatype.
  - When determining free disk space on NetBSD>=6, support its
    Quota feature.
  - Windows portability improvements.
  + GTK+ Client: Fix threading issue on shutdown.
  + Qt Client:
  - Fix toggle-downloading-by-pressing-spacebar in the file list.
  - Fix "Open URL" crash from dangling pointer.
  - Support launching downloaded files from inside Transmission.
  - On Windows, use native Windows icons.
  - Improved network status info and tooltip in the status bar.
  - Fix "Open Torrent" dialog crash in Qt 5.2.
  + Daemon:
  - On systemd systems, fix config reloading via
    'systemctl reload'.
  - Use libevent's event loop.
  - Fix discrepancy in curl SSL setup between tr-daemon and
    tr-remote.
  - Fix broken OS X build.
  + Web Client:
  - Support file renaming in the web client.
  - Fix incorrect torrent state being displayed for magnet links.
  - Make URLs in the torrent's comment field clickable (and
    sanitize them to prevent cross-scripting).
  + Mac client fixes.
- Change license to (GPL-2.0 or GPL-3.0) and MIT, following
  upstreams relicensing.
- Switch Qt build to Qt5:
  + Replqce libqt4-devel BuildRequires with libqt5-linguist and
    libqt5-qtbase-devel.
  + Change qmake calls to be qmake-qt5 and lrelease to be
    lrelease-qt5.
  + Drop transmission-qt4.patch: no longer required.
* Fri Aug  9 2013 dimstar@opensuse.org
- Update to version 2.82:
  + All Platforms:
  - Fix webseed crash.
  - Fix crash when adding UDP trackers whose host's canonical
    name couldn't be found.
  - Fix crash when sending handshakes to some peers immediately
    after adding a magnet link.
  - Fix crash when parsing incoming encrypted handshakes when the
    user is removing the related torrent.
  - Add safeguard to prevent zombie processes after running a
    script when a torrent finishes downloading.
  - Fix "bad file descriptor" error.
  - Queued torrents no longer show up as paused after exiting &
    restarting.
  - Fix 2.81 compilation error on OpenBSD.
  - Don't misidentify Tixati as BitTornado.
  + Mac Client:
  - Fix bug that had slow download speeds until editing
    preferences.
  + GTK+ Client:
  - Fix crash that occurred in some cases after using
    Torrent > Set Location.
  - Fix crash where on_app_exit() got called twice in a row.
  - Fix 2.81 compilation error on older versions of glib.
  - Can now open folders that have a '#' in their names.
  - Silence gobject warning when updating a blocklist from URL.
  + Qt Client:
  - Qt 5 support.
  + Web Client:
  - Fix syntax error in index.html's meta name="viewport".
  - Fix file uploading issue in Internet Explorer 11.
- Add transmission-qt4.patch: Revert the changes for Qt5, as we do
  not have it available yet.
* Fri Jul 19 2013 dimstar@opensuse.org
- Update to version 2.81:
  + All Platforms:
  - Fix 2.80 bug that showed the incorrect status for some peers.
  - Better handling of announce errors returned by some trackers.
  - Fix compilation error on Solaris.
  + GTK+ Client:
  - Fix minor memory leaks.
  - Remove OnlyShowIn= from the .desktop file.
  + Qt Client: Remove OnlyShowIn= from the .desktop file.
  + Daemon: Change the systemd script to start Transmission after
    the network's initialized.
  + Web Client: Slightly better compression of png files.
  + Mac client fixes.
* Sat Jun 29 2013 dimstar@opensuse.org
- Update to version 2.80:
  + All Platforms:
  - Support renaming a transfer's files and folders.
  - Remove the most frequent thread locks in libtransmission (ie,
    fewer beachballs).
  - Show the free disk space available when adding torrent.
  - Faster reading and parsing of local data files.
  - Better use of the OS's filesystem cache.
  - Lengthen the prefetch cache for data sent to peers.
  - Other small speedups.
  - Replace the previous JSON parser with jsonsl to resolve DFSG
    licensing issue.
  - Fix fails-to-build when compiling with
  - Werror=format-security.
  - Improved unit tests in libtransmission.
  - Tarballs are now released only in .xz format.
  + Mac Client:
  - Use VDKQueue for watching for torrent files.
  + GTK+ Client:
  - Simplify the tracker filter pulldown's interface (now matches
    the Qt client).
  - Synced preferences text & shortcuts.
  - Remove deprecated calls to gdk_threads_enter().
  - Silence a handful of console warnings.
  + Qt Client:
  - More efficient updates when receiving information from the
    server.
  - Add an option to play a sound when a torrent finishes
    downloading.
  - Add an option to start up iconified into the notification
    area.
  - Fix an issue with the tray icon preventing
    hibernation/logout.
  - Other CPU speedups.
  - Open the correct folder when clicking on single-file
    torrents.
  - Synced preferences text & shortcuts.
  - Fix non Latin-1 unit strings.
  + Daemon:
  - Add support for specifying recently-active torrents in
    transmission-remote.
  + Web Client:
  - Extend the cookie lifespan so that settings like sort order
    don't get lost.
  + Utils:
  - Support user-defined piece sizes in transmission-create.
- Replace systemd BuildRequires with pkgconfig(libsystemd-daemon)
  to match what configure is checking for.
- Drop transmission-fix-qt-translations-dir.patch: fixed upstream.
* Wed Mar  6 2013 nmo.marques@gmail.com
- Add transmission-daemon-systemd to sources
- Split transmission-daemon into sub-package, add systemd service
  and macros (service to be disabled by default)
- Create 'transmission' user to run transmission-daemon (dont run
  service as root).
* Tue Feb 26 2013 zaitor@opensuse.org
- Update to version 2.77:
  + All Platforms:
  - Fix 2.75 regression that broke JSON parsing of real numbers
    in locales that don't use '.' as a decimal separator.
  - Don't invalidate the OS's file cache when closing files.
  - Fix overflow error when setting speed limits above ~8589
    kB/s.
  - Generated magnet links didn't include webseeds.
  - Fix minor memory leaks when using webseeds.
  + GTK+ Client:
  - Minor pluralization fixes in the UI.
  - Fix folder mis-selection issue in the Preferences dialog.
  - Fix GTK+ console warnings on shutdown.
  + Qt Client:
  - Fix non Latin-1 symbol issue when showing file transfer
    speeds.
  - Fix issue when creating new torrents with multiple trackers.
  - Fix lost text selection in the properties dialog's 'comment'
    field.
  + Daemon: Fix documentation errors in the spec and manpages.
  + Web Client: Fix minor DOM leak.
  + CLI: Fix transmission-cli failure when the download directory
    doesn't exist.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 2.76:
  + All Platforms:
  - Better error logging when user-provided scripts can't be
    executed.
  - The "Time Remaining" property wasn't set for torrents with
    webseeds but no peers.
  - Fix rare error that created a directory name "$HOME".
  + GTK+ Client:
  - Fix sort-by-age regression introduced in 2.74.
  - The "Edit Trackers" window didn't resize properly due to a
    2.70 regression.
  - Raise the main window when presenting it from an App
    Indicator.
  + Qt Client:
  - Add magnet link support to transmission-qt.desktop.
  - Fix notification area bug that inhibited logouts & desktop
    hibernation.
  - Use the "video" icon when the torrent is an mkv or mp4 file.
  - Toggling the "Append '.part' to incomplete files' names" had
    no effect.
  - Fix display of the torrent name in the Torrent Options dialog
  - Fix cursor point bug in the filterbar's entry field.
  - Fix crash when adding a magnet link when Transmission was
    only visible in the system tray.
  - Fix free-memory-read error on shutdown.
  + Daemon:
  - Better watchdir support.
  - Documentation fixes in transmission-remote's manpage.
  + Web Client:
  - Fix indentation of the torrent list and toolbar buttons on
    mobile devices.
  + CLI:
  - If the Download directory doesn't exist, try to create it
    instead of exiting.
* Mon Dec 17 2012 vuntz@opensuse.org
- Update to version 2.75:
  + Mac-only fixes.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 2.74:
  + All Platforms:
  - Fix a bug that prevented IPv6 addresses from being saved in
    dht.dat
  - Better handling of magnet links that contain 'tr.x='
    parameters
  - Add filtering of addresses used for uTP peer connections
  - Fix detection of whether or not a peer supports uTP
    connections
  + Web Client:
  - Fix a multi-file selection bug
  - Fix bug where the upload and download arrows and rates would
    not appear for downloading torrents
  - Fix bug when displaying the tracker list
  + Mac fixes.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 2.73:
  + Mac: Fix crash on non-English localizations.
* Wed Oct 17 2012 dimstar@opensuse.org
- Update to version 2.72:
  + All Platforms:
  - Fix crash when adding magnet links with malformed webseeds.
  - Fix handling of magnet links' webseed URLs that contain
    whitespace.
  - Fix remaining time estimates of magnet links that have
    webseeds.
  - Show the webseed count in the torrent list when downloading
    from webseeds.
  + GTK+: When adding torrents by URL from the clipboard, handle
    whitespace in the link.
  + Qt: Fix dialog memory leaks.
  + Web Client: Minor interface fixes.
  + Mac fixes.
* Thu Sep 27 2012 dimstar@opensuse.org
- Update to version 2.71:
  + Mac: Fix crasher on 10.6 Snow Leopard
- Changes from version 2.70:
  + All Platforms:
  - Improved speed with the µTP protocol
  - Fix bug that caused some incoming encrypted peer connections
    to fail
  - Fix bugs with the speed limit scheduler
  - Fix crasher with magnet links
  + GTK+:
  - Require GTK+ 3.4
  + Qt:
  - Control speed limit from the icon tray
  - Improved behavior when clicking on torrents in the torrent
    list
  - Fix bug where torrent files were not deleted
  - Fix bug with unicode characters in the default location
  + Web Client:
  - The file inspector tab displays files nested under
    directories
  - Improved scrolling on iPad
  - Fix incorrectly rendered characters
  - Fix bug involving attempts to post notifications without
    permission
  - Mac fixes.
- Spec file cleanup using spec-cleaner.
* Sat Aug 25 2012 nekolayer@yandex.ru
- Add transmission-qt-lang package:
  + Enable build of translation files for transmission-qt
  + Add transmission-fix-qt-translations-dir.patch: set
    transmission translations dir to QT library translations dir.
* Tue Jul 24 2012 zaitor@opensuse.org
- Update to version 2.61:
  + GTK+:
  - Support startup notification.
  - Require GTK+ 3.
  + Qt:
  - Fix bug when opening the web client via the Preferences
    dialog.
  - Better opening of magnet links.
  - The Torrent File list now handles very long lists faster.
  - Fix i18n problem introduced in 2.60.
  + Web Client:
  - Close potential cross-scripting vulnerability from malicious
    torrent files.
  + Utils:
  - Add magnet link generation to the transmission-show command
    line tool.
  + Mac:
  - Fix crash when creating a torrent file on Lion or newer.
- Drop 0%%{?favor_gtk2} / BuildRequires: pkgconfig(gtk+-2.0), gtk2
  support dropped upstream.
- Cleanup spec by dropping a lot of unused %%if statements for
  versions of openSUSE we no longer build for.
* Fri Jul  6 2012 dimstar@opensuse.org
- Update to version 2.60:
  + All Platforms:
  - Fix issues when adding magnet links
  - Improved scraping behavior for certain trackers
  - Fix bug where cleared statistics might not save
  - Updated versions of miniupnpc and libuTP
  - Fixed compilation issues with Solaris and FreeBSD
  - Other minor fixes
  + Web Client:
  - Notification of downloading and seeding completion (requires
    browser support of notifications)
  - Re-add select all and deselect all buttons to the file
    inspector tab
  + Mac-specific changes.
  + Updated translations.
* Sat May 19 2012 zaitor@opensuse.org
- Update to version 2.52:
  + All Platforms:
  - Fix bug with zero termination of multiscrape strings.
  - Update the bundled libnatpmp and miniupnp port forwarding
    libraries.
  + GTK+:
  - Fix minor bug in Ubuntu app indicator support.
  + Mac-specific changes.
- Drop xz BuildRequires, since this comes for free in the
  buildsystem now.
* Mon Apr  9 2012 dimstar@opensuse.org
- Update to version 2.51:
  + All Platforms:
  - Update the bundled libnatpmp and miniupnp libraries for port
    forwarding
  - Add environment variable options to have libcurl verify SSL
    certs
  - Support user-specified CXX environment variables during
    compile time
  + GTK+:
  - Fix crash when adding torrents on systems without
    G_USER_DIRECTORY_DOWNLOAD
  - Honor the notification sound setting
  - Add a tooltip to files in the torrents' file list
  - Fix broken handling of the Cancel button in the "Open URL"
    dialog
  - Improve support for Gnome Shell and Unity
  - Catch SIGTERM instead of SIGKILL
  + Qt:
  - Progress bar colors are now similar to the Mac and Web
    clients'
  - Improve the "Open Folder" behavior
  + Web Client:
  - Fix global seed ratio progress bars
  - Fix sometimes-incorrect ratio being displayed in the
    Inspector
  - If multiple torrents are selected, show the aggregate info in
    the Inspector
  - Upgrade to jQuery 1.7.2
  + Daemon:
  - Show magnet link information in transmission-remote -i.
* Mon Feb 27 2012 dimstar@opensuse.org
- Conditionally use libminiupnpc-devel BuildRequires on openSUSE
  12.2 and later only. Previous openSUSE versions did not have the
  package and will make use of the miniupnp that is bundled with
  the transmission sources.
* Fri Feb 17 2012 vuntz@opensuse.org
- Add libminiupnpc-devel BuildRequires: use an external miniupnpc
  instead of a bundled copy. This needs a fix in our miniupnpc
  package to work, though.
- Remove libnotify-tools Requires from gtk subpackage: this is not
  needed anymore since transmission now uses dbus directly to
  create notifications.
* Tue Feb 14 2012 zaitor@opensuse.org
- Update to version 2.50:
  + All Platforms:
  - Fix crash when adding some magnet links.
  - Improved support for downloading webseeds with large files.
  - Gracefully handle incorrectly-compressed data from webseed
    downloads.
  - Fairer bandwidth distribution across connected peers.
  - Use less CPU when calculating undownloaded portions of large
    torrents.
  - Use the Selection Algorithm, rather than sorting, to select
    peer candidates.
  - Use base-10 units when displaying bandwidth speed and disk
    space.
  - If the OS has its own copy of natpmp, prefer it over our
    bundled version.
  - Fix Fails-To-Build error on Solaris 10 from use of mkdtemp().
  - Fix Fails-To-Build error on FreeBSD from use of alloca().
  - Fix Fails-To-Build error when building without a C++ compiler
    for libuT.
  + GTK+:
  - Fix regression that broke the "--minimized" command-line
    argument.
  - Instead of notify-send, use the org.freedesktop.Notifications
    DBus API.
  - Fix a handful of small memory leaks.
  + Qt:
  - Fix FTB when building without libuTP support on Debian.
  + Web Client:
  - Filtering by state and tracker.
  - Sorting by size.
  - Larger, easier-to-press toolbar buttons.
  - Fix the torrent size and time remaining in the inspector's
    details tab.
  - Bundle jQuery and the stylesheets to avoid third-party CDNs.
  - Upgrade to jQuery 1.7.1.
  - Fix runtime errors in IE 8, IE 9, and Opera.
  - Revise CSS stylesheets to use SASS.
  - Minor interface tweaks.
  + Daemon:
  - Fix corrupted status string in transmission-remote.
* Thu Oct 20 2011 dimstar@opensuse.org
- Update to version 2.42:
  + All Platforms:
  - Fix error connecting to UDP trackers from big-endian systems
  - Fix RPC error when editing UDP trackers
  - Fix build failure when a C++ compiler is not installed
  + Mac:
  - Fix a potential crash on 10.5 Leopard
  - Fix bugs with the tracker and file inspector tables
  + GTK+:
  - Support GTK+ 3.2
  - Fix crasher on systems not running DBus
  + Web Client
  - Fix bug which broke Opera support
  + Updated translations.
- Add conditional pkgconfig(gtk+-3.0) BuildRequires, based on
  favor_gtk2; in case favor_gtk2 evaluates to true, we stay with
  the existing gtk2-devel BuildRequires.
* Mon Oct 10 2011 vuntz@opensuse.org
- Update to version 2.41:
  + Fix crash on Mac.
* Sat Oct  8 2011 zaitor@opensuse.org
- Change notify-tools Requires to libnotify-tools (notify-tools
  doesn't exist...).
* Thu Oct  6 2011 vuntz@opensuse.org
- Update to version 2.40:
  + All Platforms:
  - Torrent queuing
  - Improved webseed support
  - Fix crash when removing a magnetized transfer
  - Fix adding transfers over RPC when a subfolder does not exist
  - Other minor fixes
  + GTK+:
  - Add GTK+ 3 support
  - Make popup notification and system sounds system-configurable
  - Add a settings option to hard-delete files instead of using
    the recycle bin
  + Qt:
  - Add popup notification for finished torrents
  - Fix non-UTF-8 display issue in the "New Torrent" dialog
  + Daemon:
  - SSL support in transmission-remote
  + Web Client:
  - Speed improvements
  - Add filtering by tracker
  - Allow preference changes on mobile devices
  - Allow compact view on mobile devices
  - Stop ratio functionality
  - Compact view interface improvements
  + Utils:
  - Fix transmission-edit bug when adding a tracker to a
    single-tracker torrent
  - Fix transmission-create bug when specifying a directory with
    a leading "./"
- Note that we can't use the GTK+ 3 support as the build system has
  not been updated for it.
- Add explicit glib2-devel BuildRequires.
- Remove dbus-1-glib-devel, libcanberra-devel, libnotify-devel
  BuildRequires: they're gone upstream.
- Add canberra-gtk-play Requires to gtk subpackage: transmission
  now uses the canberra-gtk-play binary.
- Add libnotify-tools Requires to gtk subpackage: transmission now
  uses the notify-send binary.
* Thu Jul 21 2011 vuntz@opensuse.org
- Update to version 2.33:
  + All Platforms:
  - Improved webseed support
  - Better support for moving and deleting files
  - Fix "Too many open files" bug
  - Apply blocklists towards DHT communication
  - Fix displayed availability
  + GTK+:
  - Remove deprecated GConf2 dependency
  + Qt:
  - Fix high CPU issues
  - Fix wrong torrent count on tracker filterbar
  + Updated translations.
- Remove gconf2-devel BuildRequires.
- Add dbus-1-glib-devel BuildRequires that was missing earlier, or
  was implicit before.
* Thu Jun 30 2011 dimstar@opensuse.org
- Update to version 2.32:
  + All Platforms:
  - Fix error caused by some "open-file-limit" configuration
    settings
  - Fix 2.30 problem seeding to some peers
  - Fix bug converting torrent file text contents to UTF-8
  - Better µTP support on systems running uClibc
  - Other small bug fixes
  + GTK+:
  - Fix 2.30 error opening torrents from a web browser
  - Remove GNOME desktop proxy support
  + Web Client:
  - Fix bug when adding torrents
  - Add torrents by info hash in the add dialog
  - Sorting by ratio
  - Allow drag-and-drop to add links
- Add xz BuildRequires to be able to decompress the tar.xz source.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 2.31:
  + This release fixes a bunch of packaging issues in 2.30.
- Changes from version 2.30:
  + All Platforms
  - 265TP support
  - UDP tracker support
  - Multiscrape support
  - Download scarcest pieces first
  - The "lazy bitfield" feature has been superseded by the
    "Fast Extension" BEP6
  - Scripts are passed the environment
  + GTK+:
  - Added 256 x 256 icon
  - Register as a magnet link handler in the .desktop file
  + Web Client:
  - Peer and Network preferences
* Mon Apr  4 2011 dimstar@opensuse.org
- Allow to switch on appindicators based on Project Meta data
  (WITH_APPINDICATOR).
* Thu Mar 10 2011 dimstar@opensuse.org
- Update to version 2.22:
  + All Platforms:
  - Faster endgame
  - Fix bug where leechers might be disconnected while seeding in
    some situations
  - Fix 2.20 bug that sometimes showed inaccurate upload/download
    speeds
  - Support for unsorted blacklists
  - Fix IPv6 DHT
  - Re-add support to automatically close idle peers
  - Fix bug where the resume file did not save the time checked
    for the last piece
  + GTK+:
  - Fix setting individual idle seeding time
  + Qt:
  - Fix loading localizations on Linux
  + CLI:
  - Fix bandwidth display issue
  + Updated translations.
* Sat Feb 12 2011 dimstar@opensuse.org
- Update to version 2.21:
  + Fix compilation errors of 2.20 release
  + Updated translations
- Changes from version 2.20:
  + All Platforms:
  - Remember downloaded files when a drive is unplugged
  - File re-verification is no longer needed in some situations
  - Fix "Too many open files" error
  - Show the total downloading and seeding time per torrent
  - Fix webseeds
  - Better support for IPv6-only trackers
  - Add the ability to shutdown Transmission sessions via RPC
  - NAT-PMP and UPnP now also map the UDP port
  - Update the DHT code to dht-0.18
  - Faster parsing of bencoded data
  - Improve support for running scripts when a torrent finishes
    downloading
  - Fix reannounce interval when trackers return a 404 error
  - Fix checksum error on platforms running uClibc 0.9.27 or
    older
  - Fix memmem() errors on Solaris
  + GTK+:
  - Add "Add" and "Remove" buttons to the tracker list
  - Add filesize column to the files list
  - Several minor bugfixes and interface improvements
  + Qt:
  - Accept info_hash values in the "Add url..." dialog
  + Daemon:
  - Add "reannounce to tracker" option to transmission-remote
  - transmission-remote can now read auth info from environment
    variables
  - Fix configuration file bug with transmission-daemon running
    on Macs
  + Web Client:
  - Right-clicking a torrent now works with Firefox /
    Firegestures / Ubuntu
  + Utils:
  - Fix error when replacing substrings in tracker announce URLs
  - Webseeds are now displayed in transmission-show
- BuildRequire libevent-devel >= 2.0.0 to save build power if we
  do not have the package available.
- Remove lang workaround, bnc#659001.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Sun Jan  9 2011 vuntz@opensuse.org
- Use update-alternatives to provide /usr/bin/transmission, with
  alternatives being transmission-cli, transmission-gtk and
  transmission-qt:
  + Create the ghost files in %%install.
  + Add update-alternatives Requires(post/postun) to the three
    packages.
  + Call update-alterantives in %%post/%%postun of the three
    packages.
  + The priority order is: gtk, qt, cli.
- This makes the usage of transmission from the command line a bit
  more intuitive. Fix bnc#657450.
* Sat Dec 11 2010 vuntz@opensuse.org
- Remove some locales until bnc#659001 is fixed, to fix a build
  failure.
* Fri Dec 10 2010 vuntz@opensuse.org
- Update to version 2.13:
  + All Platforms:
  - Fix "No Announce Scheduled" tracker error
  - Fix build error on Solaris 10
  - Fix RPC documentation errors
  - Fix minor packaging errors
  + GTK+:
  - Unblur the statusbar icons
  - Fix truncation error in the Torrent Properties dialog
  + Qt:
  - Fix crash when opening the Torrent Properties dialog on
    magnet links
  - Fix "undo" error when making changes in the Torrent
    Properties dialog
  + Updated translations.
* Tue Nov 16 2010 badshah400@gmail.com
- Update to version 2.12:
  + All Platforms:
  - Make the blocklist URL user-configurable
  - Several minor bug fixes and CPU speed improvements
  - Use slightly less bandwidth in DHT messages
  - Fix 2.10 build issue on uClibc systems
  + GTK+:
  - Fix 2.11 crash when opening the Properties dialog on a magnet
    link torrent
  - Fix 2.00 regression which failed to inhibit hibernation on
    laptops
  + CLI:
  - Fix 2.10 crash
  + Web Client:
  - Upgrade to jQuery 1.4.3
  - Fix 2.11 regression when using the web client on IE7 or IE8
* Mon Oct 18 2010 vuntz@opensuse.org
- Update to version 2.11:
  + All Platforms:
  - Fix a 2.10 crash
  - Fix minor build issues on various platforms, particularly
    embedded systems
  - Fix issue when saving bencoded files on small hardware
    running uClibc
  - Fix minor rounding issue when displaying percentages
  - Fix the optimistic unchoke interval
  + GTK+:
  - Fix drag-and-dropping a magnet link
  - Fix hiding dialogs when hiding Transmission in the
    notification area
  + Qt:
  - Fix crash in the file tree
  + Daemon:
  - Fix missing status message when using "transmission-remote
  - -add"
  + Web Client:
  - Add Transmission website links to the action menu
* Fri Oct  1 2010 vuntz@opensuse.org
- Update to version 2.10:
  + All Platforms:
  - Support for automatically stopping idle seeding torrents
  - Small memory cache to reduce disk IO
  - gzip compression support added to the RPC server
  - Add support for a cookies.txt file
  - Minor CPU optimizations
  + GTK+:
  - Files and folders can be opened by clicking on them in the
    files list
  - Update the interface when session changes are made via RPC
  - Fix the Details dialog to fit on a netbook screen
  + Qt:
  - Tracker announce list editing
  - New filterbar
  - Improved display for showing a torrent's tracker announces
  - Better DBUS integration
  - Support adding torrents via drag-and-drop
  - Add Desktop Notification for added/complete torrents
  - Other minor improvements
  + Web Client:
  - Peer list added to the inspector
  - Compact view mode
  - Support filtering by active and finished
  - Support sorting by size
  + Daemon:
  - Allow the .pidfile location to be set in settings.json
  + Utils
  - New command-line utility "transmission-edit" for editing
    torrent files
  - New command-line utility "transmission-show" for viewing
    torrent files
  - New command-line utility "transmission-create" for creating
    torrent files
- Change the lang package to be transmission-gtk-lang instead of
  transmission-common-lang: apparently, only the GTK+ application
  is localized.
- Do not change transmission-gtk.desktop with
  %%suse_update_desktop_file: it's already perfectly fine.
- Update transmission-qt.desktop after renaming of qtr to
  transmission-qt.
* Sun Aug  8 2010 bjorn.lie@gmail.com
- Update to version 2.04:
  + All Platforms:
  - Fix display bug in tr_truncd()
  + GTK+:
  - Fix inaccurate "active torrent" counts in the filterbar
  - Fix display bug with magnet link names
  + Qt:
  - Fix crash when accessing a password-protected remote session
  + Web Client:
  - Fix bad redirect
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.03:
  + Fix bug on Mac version.
- Changes from version 2.02:
  + All Platforms:
  - Fix NAT-PMP port forwarding issue on some systems
  - Fix filename errors for torrents whose files are encoded in
    ISO-8859-1
  - Fix rare crash on shutdown
  - Fix the RPC server's redirect URL to allow HTTPS proxies like
    stunnel
  - Replace less-portable calls with posix nanosleep()
  + GTK+:
  - Fix crash when opening the Properties dialog on a magnet link
    without metainfo
  - Fix crash when removing multiple torrents at once
  - Allow individual torrents' download speed limits to be set to
    zero
  - Fix translation error with some error messages
  + Qt:
  - Fix CPU spike when opening the Properties dialog
  - Fix compilation issue with Qt < 4.5
* Fri Jul 16 2010 vuntz@opensuse.org
- Update to version 2.01:
  + All Platforms:
  - Better tracker announce management when completed torrents
    are moved from the incomplete directory
  - Speed up moving local data from one disk to another
  - Better parsing of nonstandard magnet links
  + GTK+:
  - Faster torrent file parsing
  - Fix the magnet link options dialog does not respect setting
  - Add an error popup if "Add URL" fails
  + Qt:
  - Fix crash after getting magnet torrent metadata
  - Fix torrent ratio goals
  - Fix "add torrent" dialog bug on KDE desktops that popped up
    previous torrents
  - Fix 2.00 bug that prevented multiple instances from being run
  - Fix remote mode bug that kept the torrent list from being
    shown
  - Support encryption settings in the preferences dialog
  - Use flagStr in the status field of the peer list
  - Request a full refresh when changing the session source
  - Fix the torrent list jumping to the top when a torrent is
    removed
  + Web Client:
  - Fix display bug caused by removal of a torrent hidden by the
    current filter
* Sat Jun 19 2010 admin@djscore.org
- Update to version 2.00:
  + All Platforms:
  - "Local Peer Discovery" for finding peers on the local network
  - Optimize download requests for the bandwidth available
  - Smarter heuristics when deciding the order to connect to
    peers
  - Faster verification of local data
  - Faster startup
  - Support more blocklist file formats
  - Use IEC standard units (KiB, MiB, GiB) instead of
    (KB, MB, GB)
  - Better handling of 404 tracker errors
  + GTK+:
  - New filterbar to filter by tracker, private/public, etc.
  - Compact View replaces Minimal View, taking up considerably
    less space
  - Show the Torrent Options dialog when adding magnet links
  - "Set Location" now supports moving multiple torrents at once
  - The Properties window now fits on low resolution screens
  - Add favicon support to the Properties dialog's Tracker tab
  + Qt:
  - Show the Torrent Options dialog when adding magnet links
  - Show all active trackers in the tracker display list
  - Show file sizes in the file tree
  - Added a confirm dialog when removing torrents
  - Properties and torrent options no longer jump around while
    editing
  - Allow setting locations for remote sessions
  - Miscellaneous UI fixes
  + Daemon:
  - Let users specify a script to be invoked when a torrent
    finishes downloading
  - Better support for adding per-torrent settings when adding
    a new torrent
  - Optional pidfile support
  - Option to start torrents paused
  - Option to delete .torrent files from watch directory
  + Web Client:
  - The context menu now works when multiple rows are selected
  - Show ETA for seeding torrents that have a seed ratio set
* Mon May  3 2010 dimstar@opensuse.org
- Update to version 1.93:
  + All Platforms:
  - Fix rare crash when some peers disconnected unexpectedly
  - Fix bug which didn't parse scheduled speed limit dates
    correctly
  - Fix bug that broke magnet links whose names contained slashes
  - Fix crash when updating the blocklist when the disk is full
  - Fix slow file preallocation on Unix systems not using
    ext3/ext4
  - Fix regression which broke the "bind-address-ipv4"
    configuration setting
  - For better security, Web client connctions are disabled by
    default
  - Upgrade to miniupnpc-1.4
  - Transmission builds out-of-the-box with Curl 7.15.5.
  + GTK+:
  - Use the size for the system tray icon
  + Qt:
  - Fix bug that crashed when removing more than one torrent at
    once
  - Fix bug when parsing the remote password from the command
    line
  - Add support for the "incomplete directory" in the preferences
    dialog
  - Don't show "time remaining" for paused torrents
  + Daemon:
  - Fix bug parsing RPC requests when setting which files to not
    download
  - Fix possible crash when using inotify for the daemon's
    watchdir
  - Fix bugs in the configure script
  - Fix bug updating the blocklist over RPC
  + Web Client:
    + Fix bug that broke the "reverse sort order" menu checkbox
- Drop transmission-no-dht.patch and remove --disable-dht from
  configure.
* Fri Mar 12 2010 dimstar@opensuse.org
- Update to version 1.92:
  + All Platforms:
  - Fix possible data corruption issue caused by data sent by bad
    peers during endgame
  - Fix potential buffer overflow when adding maliciously-crafted
    magnet links
  - Fix announces to IPv6 trackers
  - Fix DNS problems on some platforms, including Debian
  - Fix issues with the incomplete directory functionality
  - Fix port forwarding error on some routers by updating
    libnatpmp and miniupnp
  + GTK+:
  - Fix directory selection error in GTK+ 2.19
  - Small GUI improvements: HIG correctness, remove deprecated
    GTK+ calls, etc.
  + Daemon:
  - Fix 1.91 build error on Mac and FreeBSD
  - Standardize the daemon's watchdir feature to behave like the
    other clients'
  + Web Client
  - Statistics dialog
  - Fix error in "trash data & remove from list" that didn't
    trash all data
  - Fix display of ratios and time
  - Update to jQuery 1.4.2
- Pass RPM_OPT_FLAGS also the the qmake built Qt UI.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 1.91:
  + All Platforms:
  - Fix 1.90 crash-on-startup bug that affected some users
  - Fix 1.90 bug that caused the "turtle mode" state to be
    forgotten between sessions
  - Fix 1.83 crash when adding a torrent by URL from an ftp
    source via the web client
  - For the BitTorrent spec's "downloaded=X" passage, use the de
    facto standard
* Wed Feb 17 2010 dimstar@opensuse.org
- Update to version 1.90:
  + All Platforms:
  - Add an option to disable the .part suffix for incomplete
    files
  - Add priority selector to GUI clients' add torrent windows
  - Fix 1.81 bug that broke HTTP requests to sites that gave HTTP
    301 redirects
  - Fix 1.8x bug in announcing "finished downloading" and
    "stopping" at the same time
  - Fix 1.8x bug in announcing partial seeds
  - Try harder to make announces finish, even if the tracker
    responds slowly
  - Fix bug that didn't honor download speed limits of 0
  - Use fallocate64() for fast file preallocation on systems that
    support it
  - Magnet link improvements
  - Don't let "Disk is full" errors cause loss of configuration
    files
  - Faster parsing of bencoded data, such as .torrent files
  + GTK+:
  - Give more helpful error messages if "Set Location" or "Add
    Magnet Link" fail
  - Add optional support for libappindicator
  - Minor build fixes
  + Daemon:
  - Add transmission-remote support for port testing and
    blocklist updating
  - Add transmission-daemon support for incomplete-dir, dht, and
    seedratio
  - If settings.json is corrupt, give an error telling where the
    problem is
  - Add option to specify where log messages should be written
  + Web Client:
  - Add a tracker tab to the inspector
  - Fix 1.8x display error when showing magnet link information
  + Qt:
  - Fix bug that prevented torrents from being added via web
    browsers
* Fri Jan 29 2010 vuntz@opensuse.org
- Update to version 1.83:
  + All platforms:
  - Fix announce error that caused uploads and downloads to
    periodically freeze
  - Fix announce timeout error that caused "no response from
    tracker" message
  - Fix "file not found" error message that stopped some torrents
  - Fix crash when adding new torrents via their ftp URL
  - Fix crash when receiving invalid request messages from peers
  - Fix error when updating the blocklist
* Sun Jan 24 2010 vuntz@opensuse.org
- Update to version 1.82:
  + The 1.81 announce did not contain the port number
- Changes from version 1.81:
  + All platforms:
  - Fix 1.80 bug that misparsed some magnet links
  - Fix 1.80 bug that caused startup to be very sluggish for some
    people
* Thu Jan 21 2010 vuntz@opensuse.org
- Update to version 1.80:
  + All platforms:
  - Add support for magnet links
  - Add support for trackerless torrents
  - Add optional "incomplete directory" where partial downloads
    are stored
  - Add .part to incomplete files' filenames
  - Find more peers by announcing to each tier in a torrent's
    tracker list, rather than only one
  - Fix vulnerability from maliciously-crafted torrent files that
    could overwrite other files
  - Improved IPv6 support
  - Improved PEX sharing with other peers
  - Faster management of large peer lists
  - DHT improvements to bootstrapping and IPv6
  - Newly-added torrents without local data don't wait in the
    "Verify Local Data" queue anymore
  - Add an OS hint to not cache local data during torrent
    verification
  - Use less CPU when making encrypted handshakes to peers
  - Better filtering of bad IP addresses
  - Fix bug that gave "too many open files" error messages
  - Fix bug that could crash Transmission on shutdown
  - Fix bug that could unpause or repause a torrent on startup
  - When uploading, improve disk IO performance by prefetching
    the data in batches
  - Portability fixes for embedded systems
  - Other small bug fixes and improvements
  + GTK+ frontend:
  - Support org.gnome.SessionManager interface for inhibiting
    hibernation
  - Added support for adding torrents by URL or magnet link
  - Add optional "download complete" sound using the XDG sound
    naming spec
  - When creating a torrent, make it easier to auto-add that new
    torrent
  - New statusbar "Ratio" icon
  - Fix minor memory leaks
  - GNOME HIG improvements
  + Daemon:
  - When running as a daemon, send log messages to syslog
  - Reload settings.json when receiving SIGHUP
  - transmission-remote now allows per-torrent speed limits to be
    set
  + Web Client:
  - Add speed limit "turtle mode" support
  - Double-clicking a torrent opens/closes the torrent inspector
  - Add "Start When Added" checkbox when adding torrents
  - Add Select All / Deselect All buttons to the file inspector
  - Add version information to the preferences dialog
  - Ensure the context menu goes away when clicking on torrents
  - Fix bug that obscured part of the context menu
- Add gconf2-devel and libcanberra-devel BuildRequires.
* Tue Jan  5 2010 mxwu@novell.com
- Update to version 1.77:
  + All Platforms:
  - Fix potential data loss by maliciously-crafted .torrent files
  - Fix minor build issues and packaging issues on various
    platforms
  - Fix 1.7x error that could unpause or repause a torrent on
    startup
  - Minor CPU speedups
  + GTK+
  - Fix crash on shutdown
  - Fix GIcon memory leak
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the fil locale for old versions of
  openSUSE.
* Thu Nov 19 2009 dimstar@opensuse.org
- Update to version 1.76:
  + All Platforms:
  - Fix potential data loss when moving torrents to where they
    already are
  - Fix minor protocol error that didn't send a port message to some peers
  - Fix minor manpage errors
  + Daemon:
  - Potential data loss when using "transmission-remote --find"
  - Fix ratio-limit bug on some uClibc systems
  - Fix invalid JSON "nan" error on optware
  + GTK:
  - Fix crash in the Preferences dialog when testing to see if
    the port is open
  - Fix crash on exit when a torrent's Properties dialog is open
  - Fix tracker address display error in the torrent Properties
    dialog
  - Fix tray menu's main window status when Transmission is
    started minimized
  - Fix broken SIGINT (ctrl-c) handling
  - Fix 1.61 build failure on systems with new versions of glib
    but older versions of gtk
  + Qt:
  - Fix crash when removing expired torrents from the display
  - Fix client from closing, rather than closing to the system
    tray, when clicking X
  - Cannot open a torrent in KDE4 with right-clicking
- Use upstream solution for transmission-no-dht.patch, from trunk.
* Sat Oct 10 2009 dimstar@opensuse.org
- Update to version 1.75:
  + All Platforms:
  - Don't wait so long on unresponsive trackers if there are
    other trackers to try
  - Adding corrupt/invalid torrents could crash Transmission
  - Fix 1.74 bug that caused a high CPU load on startup
  - Fix 1.74 bug that stopped multitracker if a single tracker
    sent an error message
  - Fix bug in converting other charsets to UTF-8
  - Handle HTTP redirects more gracefully
  - Faster verification of local data for torrents with small
    piece size
  - Fix 1.74 build error when compiling without DHT
  + GTK+:
  - Fix "sort by time remaining"
  - Fix the turtle toggle button on old versions of GTK+
  - Fix startup error if another copy of the Transmission GTK
    client is running
  - Fix clang build issue
- Refactored transmission-no-dht.patch, partially included by
  upstream.
* Sun Sep 27 2009 dimstar@opensuse.org
- Fix categories of transmission-qt, it appeared twice in the menu.
* Sat Sep  5 2009 dimstar@opensuse.org
- bnc#535391 - Add a desktop file for the Qt variant.
- Split the icons and webparts in a -common package, required by
  all variants.
- Rename the -lang package to -common-lang to reflect better where
  it belongs to.
- Obsolete transmission-lang by transmission-common.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 1.74:
  + All Platforms
  - Better data recovery in the case of an OS or Transmission
    crash
  - If a data file is moved, stop the torrent instead of
    redownloading it
  - Fix bug that didn't list some peers in the resume file and
    in PEX
  - More helpful torrent error messages
  - DHT now honors the bind-address-ipv4 configuration option
  - Fix Debian build error with miniupnpc
  - Fix Cygwin build error with strtold
  - Update to a newer snapshot of miniupnpc
  + Mac
  - 64-bit compatibility
  - Queuing system will not exclude transfers with tracker
    warnings
  - Links to original torrent files are no longer maintained
  - Fix bug where changing the global per-torrent peer connection
    limit did not affect the current session
  - Fix bug where changing settings through RPC would result in
    wrong values being saved for three fields
  + GTK+
  - Fix crash that occurred when adding torrents on some desktops
  - Synchronize the statusbar's and torrent list's speeds
  - Fix the Properties dialog's "Origin" field for multiple
    torrents
  + Qt
  - If Transmission was minimized, clicking on it the icon tray
    didn't raise it
  + Daemon
  - Speed Limit mode support added to transmission-remote
  - Add a "session stats" readout to transmission-remote
  +  Web Client
  - Progress bar shows seeding progress
  - Fix bug that displayed "%%nan" when verifying a torrent
  - "Pause All" only appeared to pause torrents with peers until
    refresh
  + Updated translations.
- Add transmission-no-dht.patch and --disable-dht in configure.
* Wed Aug 19 2009 beineri@opensuse.org
- Fix Name field of .desktop file and don't show up twice in menu.
* Sun Jul 19 2009 bjorn.lie@gmail.com
- Update to version 1.73:
  + All Platforms
  - Fix bug where user-configured peer limits could be exceeded
  - Use less memory in some high-peer situations
  - Better estimation of time left to download
  - Support supportcrypto and requirecrypto flags in http tracker
    announces
  - Update to newer snapshots of libnatpmp and miniupnpc
  - Make DHT a compile-time option
  + GTK+
  - Use GDK-safe versions of g_idle_add() and g_timeout_add*()
  - Save some space in GTK+ >= 2.16.0 by not building
    SexyIconEntry
  + Qt
  - Fix bug that crashed Qt client when setting alternative
    up/down speeds
  + Daemon
  - Add umask support
  + Web Client
  - Inspector and Add Torrent buttons for iPhone/iPod Touch
  - Add location field to inspector
  + CLI
  - Some torrent files created with transmission-cli were invalid
* Wed Jun 17 2009 vuntz@novell.com
- Update to version 1.72:
  + All Platforms
  - Fix 1.70 crash with assertion "tv->tv_usec >= 0"
  - Fix 1.70 crash with assertion "tr_peerIoSupportsFEXT(
    msgs->peer->io )"
  - Better DHT announce management
  - Fix error in reporting webseed counts via RPC
  - Better file preallocation on embedded systems
  + Mac
  - Fix problem where a small set of users could not add torrents
  + GTK+
  - Fix 1.70 crash when setting options in the Properties dialog
  - Fix a rare crash in desktop notifications
  - Can now sort the file list by priority, download, and
    completeness
  - Adding a torrent from a browser sometimes didn't work.
  - Various usability improvements
  + Daemon
  - Remote didn't always send the right Encoding header in
    requests
* Tue Jun  9 2009 vuntz@novell.com
- Update to version 1.71:
  + All Platforms
  - Fix 1.70 bug that caused high CPU use in high-peer swarms
  - Fix 1.70 build problems with DHT and libevent
  + Daemon
  - Fix watchdir issue on OSes that don't have inotify
  + GTK+
  - Fix 1.70 intltool build problem
  - Fix crash when the OS's stock mime-type icons are
    misconfigured
  - Handle very long torrent file lists faster
  + Web Client
  - Fix 1.70 bug where some torrents appeared to be duplicates
- Changes from version 1.70:
  + All Platforms
  - Distributed hash table (DHT) support for public torrents
  - Add option for moving and finding a torrent's data on the
    disk
  - JSON RPC messages can be ~85%% shorter, saving bandwidth and
    CPU
  - When available, use the system's copy of libevent instead of
    building one
  - Automatically pause torrents when verifying
  - Fix small bugs and memory leaks
  + Mac
  - Holding down the option key on launch will pause all
    transfers
  + Web Client
  - Big speed improvements, especially with large torrents
  - Fix 1.61 bug that broke adding torrents via the web client
  - Add the ability to upload multiple torrents at once
  - Torrents added by URL were always paused, regardless of
    preferences
  - Comments and announce addresses were cut off in the inspector
  - The "data remaining" field wasn't updated when the number
    reached 0
  - Smaller design adjustments
  + GTK+
  - Make it clearer that the status bar's ratio mode button is a
    button
  - Torrent comment box did not scroll, so long comments were
    partially hidden
  + Qt
  - Initial torrent list was sometimes incorrect
  - Add-torrent-and-delete-source deleted the source even if
    there was an error
  - Prefs dialog didn't show or modify "Stop seeding torrents at
    ratio"
- Add libevent-devel BuildRequires.
* Sun May 17 2009 vuntz@novell.com
- Update to version 1.61:
  + All Platforms
  - Close potential CSRF security hole for Web Client users
  - Fix locale error in the JSON parser
  + Qt
  - Various small bugfixes to the beta Qt client
  + Web Client
  - Fix 1.60 error when serving Web Client files on some embedded
    platforms
  - Add response header to allow clients to cache static files
  + Daemon
  - transmission-remote was unable to select torrents by their
    SHA1 hash
- Do not force CFLAGS and CXXFLAGS during compilation while they
  were set earlier.
- Do not add category to desktop file that is already there.
* Tue May  5 2009 opensuse@sukimashita.com
- Update to version 1.60:
  + All Platforms
  - Seed ratio limiting
  - Transfer prioritization
  - Option to specify if transfers are included in the global
    bandwidth limits
  - Random port, with optional randomization on startup
  - Improvements to UPnP port forwarding
  - Support for file preallocation on XFS filesystems
  + Mac
  - Requires Mac OS X 10.5 Leopard or newer
  - Groups (moved to preferences) can be auto-assigned to
    transfers when adding based on multiple criteria
  - Groups can have a default location when adding transfers
  - The speed limit scheduler can now be applied to only
    specific days
  - Bonjour support for the web interface
  - File filter field in the inspector
  - Option to include beta releases when auto-updating
    (using modified Sparkle 1.5)
  - Portuguese localization
  + Qt
  - New beta Qt client!
  + GTK+
  - Speed Limit: Second set of bandwidth limits that can be
    toggled or scheduled
  - Properties dialog now lets you edit/view multiple torrents
    at once
  - Allow sorting of the torrent list by size and by ETA
  - Show the file icon in the list
  + Daemon
  - Watch folder for auto-adding torrents
  - Many new features in the RPC/JSON interface
  - Allow users to specify a specific address when listening for
    peers
  + Web Client
  - File selection and prioritization
  - Add option to verify local data
  - Fix "Remove Data" bug
* Mon Apr 13 2009 mboman@suse.de
- Update to version 1.52:
  + GTK+ and Daemon
  * Always honor the XDG setting for the download directory
  + GTK+
  * Fix formatting error when showing speeds measured in MB/s
  * Fix bug that caused some scheduled speed limit time settings
    to be lost
  * Use the new blocklist URL when updating the blocklist
  + Web Client
  * On the server, better filtering of bad URLs
  * On the server, faster json serialization
  * Fix "Remove Data" bug
  * Fix minor web client 301 redirect error
  * Better Internet Explorer support
* Fri Feb 27 2009 vuntz@novell.com
- Update to version 1.51:
  + All Platforms
  - Fix configure script issues with non-gcc compilers and
    user-defined CFLAGS environment variables
  - Decrease CPU usage in some situations
  - Close a rare race condition on startup
  - More efficient use of libcurl when curl 7.18.0 or newer is
    present
  + GTK+
  - Play nicely with Ubuntu's new notification server
  - Add Pause All and Resume All buttons
  + Web Client
  - Support for Internet Explorer
  - Layout fixes when viewed on an iPhone/iPod touch
* Sat Feb 14 2009 mboman@suse.de
- Update to version 1.50:
  + All Platforms
  * IPv6 support for peers, and for trackers with explicit IPv6
    addresses
  * Improved connectivity for encrypted peers
  * Fix 1.42 error that made tracker announces slower over time
  * Fix a Mac-centric peer connection bug from 1.41
  * Use less CPU cycles when managing very fast peers
  * Better handling of non-UTF-8 torrent files
  * When removing local data, only remove data from the torrent
  * Close potential DoS vulnerability in 1.41
  * Many other bugfixes
  + GTK+
  * Various usability improvements
  * Better Gnome HIG compliance in the statusbar, properties
    dialog, and more
  + Daemon
  * Lots of new options added to transmission-remote
  * Fix 1.42 whitelist bug
  * Make i18n support optional for cli and daemon clients
  + CLI
  * Support session.json settings, just as the Daemon and GTK+
    clients do
  + Web Interface
  * Torrents can now be added by URL
  * Add the ability to "remove local data" from the web client
- Include web pages in the main package
* Tue Feb 10 2009 vuntz@novell.com
- Review changes.
* Sun Dec 28 2008 lmedinas@gmail.com
- Update to version 1.42:
  + Lot's of changes and bugfixes; see included NEWS file.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 1.40:
  + All Platforms
  - Tracker communication uses fewer resources
  - More accurate bandwidth limits
  - Reduce disk fragmentation by preallocating files
  - Stability, security, and performance improvements to the RPC/Web UI
    server
  - Support compression when serving Web UI and RPC responses
  - Simplify the RPC whitelist
  - Fix bug that prevented handshakes with encrypted BitComet peers
  - Fix 1.3x bug that could re-download some data unnecessarily
  - Lazy bitfields
  + Mac
  - Option to automatically update the blocklist weekly
  - In the file inspector tab, show progress and size for folders
  - Scrollbars correctly appear when the main window auto-resizes
  - Sparkle updated to 1.5b6
  + GTK+
  - Option to automatically update the blocklist weekly
  - Added off-hour bandwidth scheduling
  - Simplify file/priority selection in the details dialog
  - Fix a couple of crashes
  + Web Client
  - The Web Client is now out of beta
  - Minor display fixes
  - On iPhone/iPod touch, launching from the home screen hides the address
    bar
  + Daemon
  - Added the ability to get detailed peer information on torrents
  - Fix bug that didn't handle --config-dir and TRANSMISSION_HOME correctly
  - Windows portability
  + Translation updates
* Tue Sep 23 2008 maw@suse.de
- Update to version 1.34:
  + All Clients:
  * Don't reconnect too frequently to the same peer
  * Webseed bugfix
  * Fix bug that caused some transfers to not be scraped
  * Handle OpenTracker's `downloaded' key in announce responses
  + GTK+
  * Minor display fixes
  * Updated translations
  + Daemon+:
  * Minor display fixes
  + Web Client:
  * Minor display fixes
  + CLI:
  * Fix crash when creating a torrent file.
* Fri Sep 12 2008 maw@suse.de
- Update to version 1.33:
  + Too many changes and bugfixes to list; see the included NEWS
    file.
* Fri Aug 22 2008 meissner@suse.de
- actually use optflags.
* Mon Apr 14 2008 vuntz@suse.de
- Update to version 1.11:
  + Fix a couple of minor display issues
* Fri Apr  4 2008 vuntz@suse.de
- Import from the build service, with cleanups.
* Thu Apr  3 2008 awafaa@opensuse.org 
- Initial build in new repository
- Create a .changes file
* Sat Mar 29 2008 Pascal Bleser <guru@unixtech.be> 1.10
- new upstream version
* Wed Feb 27 2008 Pascal Bleser <guru@unixtech.be> 1.06
- new upstream version
* Sat Feb  9 2008 Pascal Bleser <guru@unixtech.be> 1.05
- new upstream version
* Sat Feb  2 2008 Pascal Bleser <guru@unixtech.be> 1.04
- new upstream version
* Wed Jan 30 2008 Pascal Bleser <guru@unixtech.be> 1.03
- new upstream version
* Wed Jan 23 2008 Pascal Bleser <guru@unixtech.be> 1.02
- new upstream version
* Sat Jan 12 2008 Pascal Bleser <guru@unixtech.be> 1.01
- update to 1.01
* Sat Jan  5 2008 Pascal Bleser <guru@unixtech.be> 1.00
- update to 1.00
* Wed Jan  2 2008 Pascal Bleser <guru@unixtech.be> 0.96
- update to 0.96
* Wed Dec  5 2007 Pascal Bleser <guru@unixtech.be> 0.95
- update to 0.95
* Tue Nov 27 2007 Pascal Bleser <guru@unixtech.be> 0.94
- update to 0.94
* Tue Nov 13 2007 Pascal Bleser <guru@unixtech.be> 0.93
- update to 0.93
* Mon Oct 29 2007 Pascal Bleser <guru@unixtech.be> 0.91
- removed libevent BuildRequires, has an in-tree copy that is used anyway
- update to 0.91
* Thu Oct 25 2007 Pascal Bleser <guru@unixtech.be> 0.90
- lots of upstream cleanups, dropped patches
- gettext translations are now in the main package instead of in -gtk
- several binary renames
- man pages have been removed by upstream
- uses autotools now
- zsh completion has been removed by upstream
- update to 0.90
* Wed Oct  3 2007 Pascal Bleser <guru@unixtech.be> 0.82
- cli subpackage merged in (and provided by main package)
- gtk subpackage split out
- merged with Carlos Rodgriguez' transmission spec file
- moved to openSUSE Build Service
* Sun Sep 23 2007 Pascal Bleser <guru@unixtech.be> 0.82-0.pm.1
- moved to Packman
- new upstream version
* Tue Aug  7 2007 Pascal Bleser <guru@unixtech.be> 0.80-1
- new upstream version
* Tue May  1 2007 Pascal Bleser <guru@unixtech.be> 0.72-1
- now builds transmission daemon, proxy and remote
- new upstream version
* Tue Apr 24 2007 Pascal Bleser <guru@unixtech.be> 0.71-1
- new upstream version
* Wed Apr 18 2007 Pascal Bleser <guru@unixtech.be> 0.70-1
- new upstream version
* Fri Nov 10 2006 Pascal Bleser <guru@unixtech.be> 0.6.1-2
- added patch to disable broken gtk2 version test in configure, to build properly on 10.2beta with GTK2 2.10.x and enforce >= 2.6.0 through BuildRequires instead
* Tue Aug  8 2006 Pascal Bleser <guru@unixtech.be> 0.6.1-1
- new package
